/*
 * Copyright 2015 aquenos GmbH.
 * All rights reserved.
 * 
 * Please refer to the file NOTICE.txt in the root of the source distribution or
 * in the META-INF directory of the binary archive for licensing information.
 */

package com.aquenos.epics.jackie.common.exception;

/**
 * <p>
 * Exception indicating that a message's payload was too short. There are two
 * possible reasons for such an exception.
 * </p>
 * 
 * <p>
 * Typically, this exception indicates that the payload size specified in the
 * message's header is too small to hold the data required for this kind of
 * message (e.g. to hold a value with the specified count and data-type).
 * </p>
 * 
 * <p>
 * For messages received via UDP, this exception might also indicate that end of
 * the UDP packet was reached before the message's payload could be read
 * completely. Due to the stream-like semantics of TCP, this can never happen
 * for a message received via TCP.
 * </p>
 * 
 * @author Sebastian Marsching
 */
public class ShortPayloadException extends MalformedMessageException {

    private static final long serialVersionUID = -2153188991901806407L;

    /**
     * Constructs a new exception with <code>null</code> as its detail message.
     * The cause is not initialized, and may subsequently be initialized by a
     * call to {@link #initCause}.
     */
    public ShortPayloadException() {
        super();
    }

    /**
     * Constructs a new exception with the specified detail message. The cause
     * is not initialized, and may subsequently be initialized by a call to
     * {@link #initCause}.
     * 
     * @param message
     *            the detail message. The detail message is saved for later
     *            retrieval by the {@link #getMessage()} method.
     */
    public ShortPayloadException(String message) {
        super(message);
    }

    /**
     * Constructs a new exception with the specified cause and a detail message
     * of <code>(cause==null ? null : cause.toString())</code> (which typically
     * contains the class and detail message of <code>cause</code>). This
     * constructor is useful for exceptions that are little more than wrappers
     * for other throwables.
     * 
     * @param cause
     *            the cause (which is saved for later retrieval by the
     *            {@link #getCause()} method). (A <code>null</code> value is
     *            permitted, and indicates that the cause is nonexistent or
     *            unknown.)
     */
    public ShortPayloadException(Throwable cause) {
        super(cause);
    }

    /**
     * Constructs a new exception with the specified detail message and cause.
     * Note that the detail message associated with <code>cause</code> is not
     * automatically incorporated in this exception's detail message.
     * 
     * @param message
     *            the detail message (which is saved for later retrieval by the
     *            {@link #getMessage()} method).
     * @param cause
     *            the cause (which is saved for later retrieval by the
     *            {@link #getCause()} method). (A <code>null</code> value is
     *            permitted, and indicates that the cause is nonexistent or
     *            unknown.)
     */
    public ShortPayloadException(String message, Throwable cause) {
        super(message, cause);
    }

}
