/*
 * Copyright 2015 aquenos GmbH.
 * All rights reserved.
 * 
 * Please refer to the file NOTICE.txt in the root of the source distribution or
 * in the META-INF directory of the binary archive for licensing information.
 */

package com.aquenos.epics.jackie.common.io;

/**
 * Interface for a component that needs a {@link CommunicationController}. This
 * interface provides the method through which the communication controller is
 * set, so that the component can register {@link ChannelProcessor}s and
 * {@link TimerProcessor}s with the communication controller.
 * 
 * @author Sebastian Marsching
 */
public interface CommunicationProcessor {

    /**
     * Sets the communication controller for this communication processor. The
     * communication controller provides the methods through which this
     * processor can register channels and timers. The processor should use this
     * method to register its channels (and possibly some timers), so that one
     * of its process methods will be called later. This method is only called
     * once. There are no guarantees about the thread from which this method is
     * called. In particular, the calling thread does not have to be the
     * communication thread of the communication controller and registration
     * this method performs can be active before this method returns.
     * 
     * @param communicationController
     *            communication controller responsible for this processor.
     */
    void setCommunicationController(
            CommunicationController communicationController);

}
